@@ -32,6 +32,12 @@ class PathProxy:
         
     def getModelParamPath(projectname,tag):
         return os.path.join(PathProxy.getModelTagDir(projectname,tag) , 'Param.json')
+        
+    def getProjectNames():
+        return os.listdir(PathProxy.project_path)
+    
+    def getProjectTags(projectname):
+        return os.listdir(os.path.join(PathProxy.project_path,projectname,"models"))
     
     """
     method here
